Description: Lists all of the available service-specific resources, actions, and condition keys that can be used in IAM policies to control access to AWS Compute Optimizer.

Actions, resources, and condition keys for AWS Compute Optimizer - Service Authorization Reference

# Actions, resources, and condition keys for AWS Compute Optimizer

AWS Compute Optimizer (service prefix: `compute-optimizer` ) provides the following service-specific resources, actions, and condition context keys for use in IAM permission policies.

References:

- Learn how to configure this service .

- View a list of the API operations available for this service .

- Learn how to secure this service and its resources by using IAM permission policies.

###### Topics

- Actions defined by AWS Compute Optimizer
- Resource types defined by AWS Compute Optimizer
- Condition keys for AWS Compute Optimizer

## Actions defined by AWS Compute Optimizer

You can specify the following actions in the `Action` element of an IAM policy statement. Use policies to grant permissions to perform an operation in AWS. When you use an action in a policy, you usually allow or deny access to the API operation or CLI command with the same name. However, in some cases, a single action controls access to more than one operation. Alternatively, some operations require several different actions.

The Resource types column of the Actions table indicates whether each action supports resource-level permissions. If there is no value for this column, you must specify all resources ("*") to which the policy applies in the `Resource` element of your policy statement. If the column includes a resource type, then you can specify an ARN of that type in a statement with that action. If the action has one or more required resources, the caller must have permission to use the action with those resources. Required resources are indicated in the table with an asterisk (*). If you limit resource access with the `Resource` element in an IAM policy, you must include an ARN or pattern for each required resource type. Some actions support multiple resource types. If the resource type is optional (not indicated as required), then you can choose to use one of the optional resource types.

The Condition keys column of the Actions table includes keys that you can specify in a policy statement's `Condition` element. For more information on the condition keys that are associated with resources for the service, see the Condition keys column of the Resource types table.

###### Note

Resource condition keys are listed in the Resource types table. You can find a link to the resource type that applies to an action in the Resource types (*required) column of the Actions table. The resource type in the Resource types table includes the Condition keys column, which are the resource condition keys that apply to an action in the Actions table.

For details about the columns in the following table, see Actions table .

Actions | Description | Access level | Resource types (*required) | Condition keys | Dependent actions
--- | --- | --- | --- | --- | ---
DeleteRecommendationPreferences | Grants permission to delete recommendation preferences | Write |  | compute-optimizer:ResourceType | autoscaling:DescribeAutoScalingGroups ec2:DescribeInstances rds:DescribeDBClusters rds:DescribeDBInstances
DescribeRecommendationExportJobs | Grants permission to view the status of recommendation export jobs | List |  |  |
ExportAutoScalingGroupRecommendations | Grants permission to export AutoScaling group recommendations to S3 for the provided accounts | Write |  |  | autoscaling:DescribeAutoScalingGroups compute-optimizer:GetAutoScalingGroupRecommendations
ExportEBSVolumeRecommendations | Grants permission to export EBS volume recommendations to S3 for the provided accounts | Write |  |  | compute-optimizer:GetEBSVolumeRecommendations ec2:DescribeVolumes
ExportEC2InstanceRecommendations | Grants permission to export EC2 instance recommendations to S3 for the provided accounts | Write |  |  | compute-optimizer:GetEC2InstanceRecommendations ec2:DescribeInstances
ExportECSServiceRecommendations | Grants permission to export ECS service recommendations to S3 for the provided accounts | Write |  |  | compute-optimizer:GetECSServiceRecommendations ecs:ListClusters ecs:ListServices
ExportLambdaFunctionRecommendations | Grants permission to export Lambda function recommendations to S3 for the provided accounts | Write |  |  | compute-optimizer:GetLambdaFunctionRecommendations lambda:ListFunctions lambda:ListProvisionedConcurrencyConfigs
ExportLicenseRecommendations | Grants permission to export license recommendations to S3 for the provided account(s) | Write |  |  | compute-optimizer:GetLicenseRecommendations ec2:DescribeInstances
ExportRDSDatabaseRecommendations | Grants permission to export rds recommendations to S3 for the provided accounts | Write |  |  | compute-optimizer:GetRDSDatabaseRecommendations rds:DescribeDBClusters rds:DescribeDBInstances
GetAutoScalingGroupRecommendations | Grants permission to get recommendations for the provided AutoScaling groups | List |  |  | autoscaling:DescribeAutoScalingGroups
GetEBSVolumeRecommendations | Grants permission to get recommendations for the provided EBS volumes | List |  |  | ec2:DescribeVolumes
GetEC2InstanceRecommendations | Grants permission to get recommendations for the provided EC2 instances | List |  |  | ec2:DescribeInstances
GetEC2RecommendationProjectedMetrics | Grants permission to get the recommendation projected metrics of the specified instance | List |  |  | ec2:DescribeInstances
GetECSServiceRecommendationProjectedMetrics | Grants permission to get the recommendation projected metrics of the specified ECS service | List |  |  |
GetECSServiceRecommendations | Grants permission to get recommendations for the provided ECS services | List |  |  | ecs:ListClusters ecs:ListServices
GetEffectiveRecommendationPreferences | Grants permission to get recommendation preferences that are in effect | Read |  | compute-optimizer:ResourceType | autoscaling:DescribeAutoScalingGroups autoscaling:DescribeAutoScalingInstances ec2:DescribeInstances rds:DescribeDBClusters rds:DescribeDBInstances
GetEnrollmentStatus | Grants permission to get the enrollment status for the specified account | List |  |  |
GetEnrollmentStatusesForOrganization | Grants permission to get the enrollment statuses for member accounts of the organization | List |  |  |
GetLambdaFunctionRecommendations | Grants permission to get recommendations for the provided Lambda functions | List |  |  | lambda:ListFunctions lambda:ListProvisionedConcurrencyConfigs
GetLicenseRecommendations | Grants permission to get license recommendations for the specified account(s) | List |  |  | ec2:DescribeInstances
GetRDSDatabaseRecommendationProjectedMetrics | Grants permission to get the recommendation projected metrics of the specified instance | List |  |  | rds:DescribeDBClusters rds:DescribeDBInstances
GetRDSDatabaseRecommendations | Grants permission to get rds recommendations for the specified account(s) | List |  |  | rds:DescribeDBClusters rds:DescribeDBInstances
GetRecommendationPreferences | Grants permission to get recommendation preferences | Read |  | compute-optimizer:ResourceType |
GetRecommendationSummaries | Grants permission to get the recommendation summaries for the specified account(s) | List |  |  |
PutRecommendationPreferences | Grants permission to put recommendation preferences | Write |  | compute-optimizer:ResourceType | autoscaling:DescribeAutoScalingGroups autoscaling:DescribeAutoScalingInstances ec2:DescribeInstances rds:DescribeDBClusters rds:DescribeDBInstances
UpdateEnrollmentStatus | Grants permission to update the enrollment status | Write |  |  |

## Resource types defined by AWS Compute Optimizer

AWS Compute Optimizer does not support specifying a resource ARN in the `Resource` element of an IAM policy statement. To allow access to AWS Compute Optimizer, specify `"Resource": "*"` in your policy.

## Condition keys for AWS Compute Optimizer

AWS Compute Optimizer defines the following condition keys that can be used in the `Condition` element of an IAM policy. You can use these keys to further refine the conditions under which the policy statement applies. For details about the columns in the following table, see Condition keys table .

To view the global condition keys that are available to all services, see Available global condition keys .

Condition keys | Description | Type
--- | --- | ---
compute-optimizer:ResourceType | Filters access by the resource type | String

Did this page help you? - Yes

Thanks for letting us know we're doing a good job!

If you've got a moment, please tell us what we did right so we can do more of it.

Did this page help you? - No

Thanks for letting us know this page needs work. We're sorry we let you down.

If you've got a moment, please tell us how we can make the documentation better.